/*************************************************************************
Title:    example program for the Interrupt controlled UART library
Author:   Fleury
File:     $Id: test_uart.c,
Datum:	  
Software: AVR-GCC 3.3
Hardware: any AVR with built-in UART, tested on ATmega8 at 4 Mhz

DESCRIPTION:
          This example shows how to use the UART library uart.c

*************************************************************************/
#include <stdlib.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/eeprom.h>

#include "uart.h" 

// command sequences im EEPROM (first program Flash, then EEPROM)
const uint8_t eeMenue[] EEMEM = { 0x02, 0x21, 0x32, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x9D, 0x2A };
const uint8_t eeExit[] EEMEM  = { 0x02, 0x21, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x5C, 0x2A };

unsigned int c, iState;
char cSend;

// Sends a 19 character command found in EEPROM
void SendCommand(unsigned int iNo)
{
  unsigned int i;  
	//for(i =0; i<=iNo*19; i++)
	for  (i = (18 * iNo); i <= ((19 * iNo) + 18); i++ )
  {
		cSend = eeprom_read_byte(&eeMenue[i]);
		uart_putc(cSend);
  }
}

int main(void)
{

  PORTD = 0x0C;    // pull ups for key inputs  PortD2 and portD3
	
  DDRB = 0x30;	   // outputs for LEDs
  PORTB = 0x30;    // LEDs off
 
  /*
   *  Initialize UART library, pass baudrate and AVR cpu clock
   *  with the macro 
   *  UART_BAUD_SELECT() (normal speed mode )
   */
   uart_init(UBRR_VAL);
  //uart_init( UART_BAUD_SELECT(UART_BAUD_RATE,F_CPU) ); 
  
  /*
   * now enable interrupt, since UART library is interrupt controlled
   */
  sei();
  
  
	iState = 0;
  for(;;)
    {  
		if (iState != PIND)  // Key state changed ?
		{
		  _delay_ms(50);
			if ((PIND & 0x08) == 0x00)        // one key
		  {			  
			  PORTB = 0x20;
				SendCommand(0);
	  	}
			else
			{
				if ((PIND & 0x04) == 0x00)			// other key
			  {				  
				  PORTB = 0x10;
			  	SendCommand(1);
		  	}
				else
				{
					if ((PIND & 0x0C) == 0x0C)   // no key
				  {
					  PORTB = 0x30;
			  	}
				}
			}
			iState = PIND;
			_delay_ms(2000);  // dirty "debounce"
		}
  }
    
}
